from __future__ import print_function

import sys
import argparse

divide = "   "
separator = "*" * 30
sub_separator = "-" * 30

parser = argparse.ArgumentParser(
    description="""Mental model simulation program.
    INPUT:
    Please provide the statements to infer from form in the form of a text file in the following format:
        Some artists are beekeepers.
        All beekeepers are chemists.
    !IMPORTANT: DO NOT ENTER \"THE\", \"OF\", ETC.
    Specify the input text file via command line argument in the following form:
        $ python syllogism.py --file beekeeper.txt""")

parser.add_argument("--file", type=str,
    default="test.txt", help="Filename containing the statements to evaluate. Default is test.txt")


class Subject:
    """Class reperesenting the arguments in the mental model"""

    def __init__(self, A, all):
        self.all = all
        self.object = A

    def __str__(self):
        return "[" + self.object + "]" if self.all else self.object

    def to_statement(self):
        s = "All" if all else "Some"
        return s + " " + self.object

class MentalModel:
    """A class representing the human mental model"""

    def __init__(self, statement):
        args = statement.split()

        if len(args) > 5 or len(args) < 4:
            print("""The statements given were not in the correct format. See 
                $ python syllogism.py --help
            for correct usage""")
            sys.exit(1)

        self.arg1 = Subject(args[1], args[0] == "all")

        if len(args) == 4:
            self.denial = False
            self.arg2 = Subject(args[3], False)
            self.statement = self.arg1.__str__() + divide + self.arg2.__str__()
        elif args[3] == "not":
            self.denial = True
            self.arg2 = Subject(args[4], args[0] == "all")
            self.statement = self.arg1.__str__() + divide + "\n" + self.arg2.__str__()
        else:
            print("""The statements given were not in the correct format. See 
                $ python syllogism.py --help
            for correct usage""")
            sys.exit(1)

    def __str__(self):
        return self.statement + "\n" + self.statement

    def __repr__(self):
        return self.statement

    def join(self, model):
        conclusions = []
        if self.arg1.object == model.arg1.object:
            """B, A ; B, C"""
            B = self.arg1
            A = self.arg2
            C = model.arg2
            how = ("left", "left")

        elif self.arg1.object == model.arg2.object:
            """B, A; C, B"""
            B = self.arg1
            A = self.arg2
            C = model.arg1
            model2 = model
            how = ("left", "right")

        elif self.arg2.object == model.arg1.object:
            """A, B ; B, C"""
            B = self.arg2
            A = self.arg1
            C = model.arg2
            how = ("right", "left")

        elif self.arg2.object == model.arg2.object:
            """A, B ; C, B"""
            B = self.arg2
            A = self.arg1
            C = model.arg1
            how = ("right", "right")

        conclusion1 = "All " + A.object + " are " + C.object
        conclusion2 = "All " + C.object + " are " + A.object
        conclusion3 = "Some " + A.object + " are " + C.object
        conclusion4 = "Some " + C.object + " are " + A.object
        conclusion5 = "All " + A.object + " are not " + C.object
        conclusion6 = "All " + C.object + " are not " + A.object
        conclusion7 = "Some " + A.object + " are not " + C.object
        conclusion8 = "Some " + C.object + " are not " + A.object

        if how == ("left", "left"):
            if self.arg1.all:  # [B] ???
                if not self.denial:
                    if model.arg1.all:
                        if not model.denial:
                            """[B] A, [B] C 33"""
                            print("Model 1...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print("Possible Conclusions: ")
                            print(conclusion1)
                            print(conclusion2)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print(" "*len(B.__str__()) + A.__str__() + divide + C.__str__())
                            print(conclusion3)
                            print(conclusion4)
                            conclusions.append(conclusion3)
                            conclusions.append(conclusion4)
                        else:
                            """[B] A, [B] -[C] 35"""
                            print("Model 1...")
                            print(B.__str__() + divide + A.__str__() + divide + "-" + C.__str__())
                            print(conclusion7)
                            conclusions.append(conclusion7)
                            print("Model 2...")
                            print(B.__str__() + divide + A.__str__() + divide + "-" + C.__str__())
                            print(conclusion7)
                            conclusions.append(conclusion7)
                    else:
                        if not model.denial:
                            """[B] A, B C 34"""
                            print("Model 1...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print(conclusion1)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print(" "*len(B.__str__()) + A.__str__() + divide + C.__str__())                            
                            print(conclusion3)
                            print(conclusion4)
                            conclusions.append(conclusion3)
                            conclusions.append(conclusion4)
                        else:
                            """[B] A, B -C 36"""
                            print("Model 1...")
                            print(B.__str__() + divide + A.__str__() + divide + "-" + C.__str__())
                            print(conclusion5)
                            print(conclusion6)
                            print(conclusion7)
                            print("Model 2...")
                            print(B.__str__() + divide + A.__str__() + divide + "-" + C.__str__())
                            print(" "*len(B.__str__()) + divide + A.__str__() + divide + "-" + C.__str__())
                            print(conclusion7)
                else:
                    if model.arg1.all:
                        if not model.denial:
                            """[B] -[A], [B] C 49"""
                            print("Model 1...")
                            print(B.__str__() + divide + C.__str__() + divide +  "-" + A.__str__())
                            print("Possible Conclusions: ")
                            print(conclusion5)
                            print(conclusion6)
                            print(conclusion8)
                            print("Model 2...")
                            print(B.__str__() + divide + C.__str__() + divide + "-" + A.__str__())
                            print(" "*len(B.__str__()) + C.__str__() + divide + A.__str__())
                            print(conclusion8)
                            conclusions.append(conclusion8)
                        else:
                            """[B] -A, [B] -C 51"""
                            print(B.__str__() + divide + "-" + A.__str__() + divide + "-" + C.__str__())
                            print(" "*len(B.__str__()) + divide + A.__str__())
                            print(" "*len(B.__str__()) + divide + " "*len(A.__str__()) + divide + C.__str__())
                    else:
                        if not model.denial:
                            """[B] -[A], B C 50"""
                            print("Model 1...")
                            print(B.__str__() + divide + "-" + A.__str__() + C.__str__())
                            print(conclusion7)
                            print(conclusion8)
                            print(conclusion5)
                            print(conclusion6)
                            print("Model 2...")
                            print(B.__str__() + divide + "-" + A.__str__())
                            print(B.object + divide + "-" + A.__str__() + divide + C.__str__())
                            print(conclusion8)
                            conclusions.append(conclusion8)
                        else:
                            """[B] -[A], B -C 52"""
                            print(B.__str__() + divide + "-" + A.__str__())
                            print(B.object + divide + "-" + A.__str__() + divide + "-" + C.__str__())
            else:  # B ???
                if not self.denial:
                    if model.arg1.all:
                        if not model.denial:
                            """B A, [B] C 41"""
                            print("Model 1...")
                            print("[" + B.object + "]" + divide + A.__str__() + divide + C.__str__())
                            print(conclusion1)
                            print(conclusion2)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print("[" + B.object + "]" + divide + A.__str__())
                            print(B.object + divide + " "*len(A.__str__()) + divide + C.__str__())
                            print(conclusion3)
                            print(conclusion4)
                            conclusions.append(conclusion3)
                            conclusions.append(conclusion4)
                        else:
                            """B A, [B] -[C] 43"""
                            print("Model 1...")
                            print(A.object + divide + "[" +  B.object + "]" + divide + "-" + C.__str__())
                            print(conclusion5)
                            print(conclusion6)
                            print(conclusion7)
                            print(conclusion8)
                            print("Model 2...")
                            print(A.object + divide +  B.object + divide + "-" + C.object)
                            print(A.object + divide + " "*len(B.object) + divide + C.object)
                            print(" "*len(A.object) + divide + " "*len(B.object) + divide + C.object)
                            print(conclusion7)
                            print(conclusion8)
                            print("Model 3...")
                            print(A.object + divide +  B.object + divide + "-" + C.object)
                            print(A.object + divide + " "*len(B.object) + divide + "[" + C.object + "]")
                            print(conclusion7)
                            conclusions.append(conclusion7)
                    else:
                        if not model.denial:
                            """B A, B C 42"""
                            print("Model 1...")
                            print(B.object + divide + A.object + divide + C.object)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.object + divide + A.object)
                            print(B.object + divide + " "*len(A.object) + divide + C.object)
                        else:
                            """B A, B -C 44"""
                            print("Model 1...")
                            print(B.object + divide + A.object + divide + "-" + C.object)
                            print(conclusion7)
                            print(conclusion8)
                            print("Model 2...")
                            print(B.object + divide + A.object)
                            print(B.object + divide + " "*len(A.object) + divide + "-" + C.object)
                else:
                    if model.arg1.all:
                        if not model.denial:
                            """B -A, [B] C 57"""
                            print("Model 1...")
                            print("[" + B.__str__() + "]" + divide + C.__str__() + divide + "-" + A.__str__())
                            print(conclusion5)
                            print(conclusion6)
                            print(conclusion8)
                            print("Model 2...")
                            print("[" + B.__str__() + "]" + divide + C.__str__() + divide + "-" + A.__str__())
                            print(" "*len(B.__str__()) + divide + C.__str__() + divide + "-" + A.__str__())
                            print(conclusion8)
                            conclusions.append(conclusion8)
                        else:
                            """B -A, [B] -C 59"""
                            print("[" + B.__str__() + "]" + divide + "-" + C.__str__())
                            print(B.object + divide + "-" + A.__str__()) 
                    else:
                        if not model.denial:
                            """B -A, B C 58"""
                            print("Model 1...")
                            print(B.object + divide + A.object + divide + C.object)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.object + divide + A.object)
                            print(B.object + divide + " "*len(A.object) + divide + C.object)
                        else:
                            """B -A, B -C 60"""
                            print("Model 1...")
                            print(B.object + divide + "-" + A.object + divide + "-" + C.object)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.object + divide + "-" + A.object)
                            print(B.object + divide + " "*len(A.object) + divide + "-" + C.object)
                            print(" "*len(B.object) + divide + A.object + divide + C.object)
    
        elif how == ("left", "right"):
            if self.arg1.all:  # [B] ???
                if not self.denial:
                    if model.arg1.all:
                        if not model.denial:
                            """[B] A, [C] B 37"""
                            print("Model 1...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print("Possible Conclusions: ")
                            print(conclusion1)
                            print(conclusion2)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print(" "*len(B.__str__()) + A.__str__() + divide + C.__str__())
                            print(conclusion3)
                            print(conclusion4)
                            conclusions.append(conclusion3)
                            conclusions.append(conclusion4)
                        else:
                            """[B] A, [C] -[B] 39"""
                            print("Model 1...")
                            print(B.__str__() + divide + A.__str__() + divide + "-" + C.__str__())
                            print(conclusion7)
                            conclusions.append(conclusion7)
                            print("Model 2...")
                            print(B.__str__() + divide + A.__str__() + divide + "-" + C.__str__())
                            print(conclusion7)
                            conclusions.append(conclusion7)
                    else:
                        if not model.denial:
                            """[B] A, C B 38"""
                            print("Model 1...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print(conclusion1)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print(" "*len(B.__str__()) + A.__str__() + divide + C.__str__())                            
                            print(conclusion3)
                            print(conclusion4)
                            conclusions.append(conclusion3)
                            conclusions.append(conclusion4)
                        else:
                            """[B] A, C -B 40"""
                            print("Model 1...")
                            print(B.__str__() + divide + A.__str__())
                            print("-" + B.object + divide + " "*len(A.__str__()) + C.object)
                else:
                    if model.arg1.all:
                        if not model.denial:
                            """[B] -[A], [C] B 53"""
                            print("[" + C.__str__() + divide + B.object + "]" + "-" + A.__str__())
                            print(conclusion5)
                            print(conclusion6)
                            conclusions.append(conclusion5)
                            conclusions.append(conclusion6)
                        else:
                            """[B] -[A], [C] -B 55"""
                            print(B.__str__() + divide + "-" + A.__str__() + divide + "-" + C.__str__())
                            print(" "*len(B.__str__()) + divide + A.__str__())
                            print(" "*len(B.__str__()) + divide + " "*len(A.__str__()) + divide + C.__str__())
                    else:
                        if not model.denial:
                            """[B] -[A], C B 54"""
                            print("Model 1...")
                            print(B.__str__() + divide + "-" + A.__str__() + C.__str__())
                            print(conclusion7)
                            print(conclusion8)
                            print(conclusion5)
                            print(conclusion6)
                            print("Model 2...")
                            print(B.__str__() + divide + "-" + A.__str__())
                            print(B.object + divide + "-" + A.__str__() + divide + C.__str__())
                            print(conclusion8)
                            conclusions.append(conclusion8)
                        else:
                            """[B] -[A], C -B 56"""
                            print(B.__str__() + divide + "-" + A.__str__())
                            print("-" + B.object + divide + "*"*len(A.__str__()) + divide + C.__str__())
            else:  # B ???
                if not self.denial:
                    if model.arg1.all:
                        if not model.denial:
                            """B A, [C] B 45"""
                            print("Model 1...")
                            print(C.__str__() + divide + B.__str__() + divide + A.__str__())
                            print(conclusion2)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(C.__str__() + divide + B.__str__() + divide + A.__str__())
                            print(" "*len(C.__str__()) + B.__str__() + divide + A.__str__())                            
                            print(conclusion3)
                            print(conclusion4)
                            conclusions.append(conclusion3)
                            conclusions.append(conclusion4)
                        else:
                            """B A, [C] -[B] 47"""
                            print("Model 1...")
                            print(A.object + divide + "[" +  B.object + "]" + divide + "-" + C.__str__())
                            print(conclusion5)
                            print(conclusion6)
                            print(conclusion7)
                            print(conclusion8)
                            print("Model 2...")
                            print(A.object + divide +  B.object + divide + "-" + C.object)
                            print(A.object + divide + " "*len(B.object) + divide + C.object)
                            print(" "*len(A.object) + divide + " "*len(B.object) + divide + C.object)
                            print(conclusion7)
                            print(conclusion8)
                            print("Model 3...")
                            print(A.object + divide +  B.object + divide + "-" + C.object)
                            print(A.object + divide + " "*len(B.object) + divide + "[" + C.object + "]")
                            print(conclusion7)
                            conclusions.append(conclusion7)
                    else:
                        if not model.denial:
                            """B A, C B 46"""
                            print("Model 1...")
                            print(B.object + divide + A.object + divide + C.object)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.object + divide + A.object)
                            print(B.object + divide + " "*len(A.object) + divide + C.object)
                        else:
                            """B A, C -B 48"""
                            print(B.object + divide + A.object)
                            print(C.object + divide + " "*len(A.object) + divide + "-" + B.object)
                else:
                    if model.arg1.all:
                        if not model.denial:
                            """B -A, [C] B 61"""
                            print("Model 1...")
                            print(C.__str__() + B.object + divide + "-" + A.object)
                            print(conclusion5)
                            print(conclusion6)
                            print(conclusion8)
                            print("Model 2...")
                            print(C.__str__() + B.object + divide)
                            print(C.__str__() + B.object + divide + A.object)
                            print(conclusion8)
                            conclusions.append(conclusion8)
                        else:
                            """B -A, [C] -B 63"""
                            print(B.object + divide + "-" + A.object)
                            print(C.__str__() + divide + " "*len(A.object) + divide + "-" + B.object)
                    else:
                        if not model.denial:
                            """B -A, C B 62"""
                            print("Model 1...")
                            print(B.object + divide + A.object + divide + C.object)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.object + divide + A.object)
                            print(B.object + divide + " "*len(A.object) + divide + C.object)
                        else:
                            """B -A, C -B 64"""
                            print(B.object + divide + "-" + A.object)
                            print(C.__str__() + divide + " "*len(A.object) + divide + "-" + B.object)
                
        elif how == ("right", "left"):
            if self.arg1.all:  # [B] ???
                if not self.denial:
                    if model.arg1.all:
                        if not model.denial:
                            """[A] B, [B] C"""
                            print("Model 1...")
                            print(B.__str__()+ divide + A.__str__() + divide + C.__str__())
                            print("Possible Conclusions: ")
                            print(conclusion1)
                            print(conclusion2)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print(" "*len(B.__str__()) + A.__str__() + divide + C.__str__())
                            print(conclusion3)
                            print(conclusion4)
                            conclusions.append(conclusion3)
                            conclusions.append(conclusion4)
                        else:
                            """[A] B, [B] -[C]"""
                            print("[" + A.object + divide + "[" + B.object + "]" + "]" + divide + "-" + C.__str__())
                            print(conclusion5)
                            print(conclusion6)
                            conclusions.append(conclusion5)
                            conclusions.append(conclusion6)
                    else:
                        if not model.denial:
                            """[A] B, B C"""
                            print(A.__str__() + divide + B.object + divide + C.object)
                            print(conclusion3)
                            conclusions.append(conclusion3)
                        else:
                            """[A] B, B -C"""
                            print(A.__str__() + divide + B.object + divide + "-" + C.object)
                            print(conclusion7)
                            conclusions.append(conclusion7)
                else:
                    if model.arg1.all:
                        if not model.denial:
                            """[A] -[B], [B] C"""
                            print("Model 1...")
                            print(B.__str__() + divide + C.__str__() + divide +  "-" + A.object)
                            print("Possible Conclusions: ")
                            print(conclusion5)
                            print(conclusion6)
                            print(conclusion8)
                            print("Model 2...")
                            print(B.__str__() + divide + C.__str__() + divide + "-" + A.object)
                            print(" "*len(B.__str__()) + C.__str__() + divide + A.object)
                            print(conclusion8)
                            conclusions.append(conclusion8)
                        else:
                            """[A] -[B], [B] -C"""
                            print(B.__str__() + divide + "-" + A.__str__() + divide + "-" + C.__str__())
                            print(" "*len(B.__str__()) + divide + A.__str__())
                            print(" "*len(B.__str__()) + divide + " "*len(A.__str__()) + divide + C.__str__())
                    else:
                        if not model.denial:
                            """[A] -[B], B C"""
                            print("Model 1...")
                            print(B.__str__() + divide + "-" + A.__str__() + C.__str__())
                            print(conclusion7)
                            print(conclusion8)
                            print(conclusion5)
                            print(conclusion6)
                            print("Model 2...")
                            print(B.__str__() + divide + "-" + A.__str__())
                            print(B.object + divide + "-" + A.__str__() + divide + C.__str__())
                            print(conclusion8)
                            conclusions.append(conclusion8)
                        else:
                            """[A] -[B], B -C"""
                            print(A.__str__() + divide + "-" + B.__str__() + divide + "-" + C.__str__())
                            print(" "*len(A.__str__()) + divide + B.__str__())
                            print(" "*len(A.__str__()) + divide + " "*len(B.__str__()) + divide + C.__str__())
            else:  # B ???
                if not self.denial:
                    if model.arg1.all:
                        if not model.denial:
                            """A B, [B] C"""
                            print("Model 1...")
                            print("[" + B.object + "]" + divide + A.__str__() + divide + C.__str__())
                            print(conclusion1)
                            print(conclusion2)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print("[" + B.object + "]" + divide + A.__str__())
                            print(B.object + divide + " "*len(A.__str__()) + divide + C.__str__())
                            print(conclusion3)
                            print(conclusion4)
                            conclusions.append(conclusion3)
                            conclusions.append(conclusion4)
                        else:
                            """A B, [B] -[C]"""
                            print("Model 1...")
                            print(A.object + divide + "[" +  B.object + "]" + divide + "-" + C.__str__())
                            print(conclusion5)
                            print(conclusion6)
                            print(conclusion7)
                            print(conclusion8)
                            print("Model 2...")
                            print(A.object + divide +  B.object + divide + "-" + C.object)
                            print(A.object + divide + " "*len(B.object) + divide + C.object)
                            print(" "*len(A.object) + divide + " "*len(B.object) + divide + C.object)
                            print(conclusion7)
                            print(conclusion8)
                            print("Model 3...")
                            print(A.object + divide +  B.object + divide + "-" + C.object)
                            print(A.object + divide + " "*len(B.object) + divide + "[" + C.object + "]")
                            print(conclusion7)
                            conclusions.append(conclusion7)
                    else:
                        if not model.denial:
                            """A B, B C"""
                            print("Model 1...")
                            print(B.object + divide + A.object + divide + C.object)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.object + divide + A.object)
                            print(B.object + divide + " "*len(A.object) + divide + C.object)
                        else:
                            """A B, B -C"""
                            print("Model 1...")
                            print(B.object + divide + A.object + divide + "-" + C.object)
                            print(conclusion7)
                            print(conclusion8)
                            print("Model 2...")
                            print(B.object + divide + A.object)
                            print(B.object + divide + " "*len(A.object) + divide + "-" + C.object)
                else:
                    if model.arg1.all:
                        if not model.denial:
                            """A -B, [B] C"""
                            print(A.object + divide + "-" + B.object)
                            print(" "*len(A.object) + divide + "[" + B.object + "]" + divide + C.object)
                        else:
                            """A -B, [B] -C"""
                            print(A.object + divide + "-" + B.object)
                            print(" "*len(A.object) + divide + "[" + B.object + "]" + divide + "-" + C.__str__())
                    else:
                        if not model.denial:
                            """A -B, B C"""
                            print(A.object + divide + "-" + B.object)
                            print(" "*len(A.object) + divide + B.object + divide + C.object)
                        else:
                            """A -B, B -C"""
                            print(A.object + divide + "-" + B.object)
                            print(" "*len(A.object) + divide + B.object + divide + "-" + C.object)
                                
        elif how == ("right", "right"):
            if self.arg1.all:  # [B] ???
                if not self.denial:
                    if model.arg1.all:
                        if not model.denial:
                            """[A] B, [C] B"""
                            print("Model 1...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print("Possible Conclusions: ")
                            print(conclusion1)
                            print(conclusion2)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.__str__() + divide + A.__str__() + divide + C.__str__())
                            print(" "*len(B.__str__()) + A.__str__() + divide + C.__str__())
                            print(conclusion3)
                            print(conclusion4)
                            conclusions.append(conclusion3)
                            conclusions.append(conclusion4)
                        else:
                            """[A] B, [C] -[B]"""
                            print("[" + A.object + divide + "[" + B.object + "]" + "]" + divide + "-" + C.__str__())
                            print(conclusion5)
                            print(conclusion6)
                            conclusions.append(conclusion5)
                            conclusions.append(conclusion6)
                    else:
                        if not model.denial:
                            """[A] B, C B"""
                            print(A.__str__() + divide + B.object + divide + C.object)
                            print(conclusion3)
                            conclusions.append(conclusion3)
                        else:
                            """[A] B, C -B"""
                            print(B.__str__() + divide + "-" + A.__str__() + divide + "-" + C.__str__())
                            print(" "*len(B.__str__()) + divide + A.__str__())
                            print(" "*len(B.__str__()) + divide + " "*len(A.__str__()) + divide + C.__str__())
                else:
                    if model.arg1.all:
                        if not model.denial:
                            """[A] -B, [C] B"""
                            print("[" + C.__str__() + divide + B.object + "]" + "-" + A.__str__())
                            print(conclusion5)
                            print(conclusion6)
                            conclusions.append(conclusion5)
                            conclusions.append(conclusion6)
                        else:
                            """[A] -B, [C] -B"""
                            print(B.__str__() + divide + "-" + A.__str__() + divide + "-" + C.__str__())
                            print(" "*len(B.__str__()) + divide + A.__str__())
                            print(" "*len(B.__str__()) + divide + " "*len(A.__str__()) + divide + C.__str__())
                    else:
                        if not model.denial:
                            """[A] -[B], C B"""
                            print("Model 1...")
                            print(B.__str__() + divide + "-" + A.__str__() + C.__str__())
                            print(conclusion7)
                            print(conclusion8)
                            print(conclusion5)
                            print(conclusion6)
                            print("Model 2...")
                            print(B.__str__() + divide + "-" + A.__str__())
                            print(B.object + divide + "-" + A.__str__() + divide + C.__str__())
                            print(conclusion8)
                            conclusions.append(conclusion8)
                        else:
                            """[A] -[B], C -B"""
                            print(B.__str__() + divide + "-" + A.__str__())
                            print("-" + B.object + divide + "*"*len(A.__str__()) + divide + C.__str__())
            else:  # B ???
                if not self.denial:
                    if model.arg1.all:
                        if not model.denial:
                            """A B, [C] B"""
                            print("Model 1...")
                            print(C.__str__() + divide + B.__str__() + divide + A.__str__())
                            print(conclusion2)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(C.__str__() + divide + B.__str__() + divide + A.__str__())
                            print(" "*len(C.__str__()) + B.__str__() + divide + A.__str__())                            
                            print(conclusion3)
                            print(conclusion4)
                            conclusions.append(conclusion3)
                            conclusions.append(conclusion4)
                        else:
                            """A B, [C] -[B]"""
                            print("Model 1...")
                            print(A.object + divide + "[" +  B.object + "]" + divide + "-" + C.__str__())
                            print(conclusion5)
                            print(conclusion6)
                            print(conclusion7)
                            print(conclusion8)
                            print("Model 2...")
                            print(A.object + divide +  B.object + divide + "-" + C.object)
                            print(A.object + divide + " "*len(B.object) + divide + C.object)
                            print(" "*len(A.object) + divide + " "*len(B.object) + divide + C.object)
                            print(conclusion7)
                            print(conclusion8)
                            print("Model 3...")
                            print(A.object + divide +  B.object + divide + "-" + C.object)
                            print(A.object + divide + " "*len(B.object) + divide + "[" + C.object + "]")
                            print(conclusion7)
                            conclusions.append(conclusion7)
                    else:
                        if not model.denial:
                            """A B, C B"""
                            print("Model 1...")
                            print(B.object + divide + A.object + divide + C.object)
                            print(conclusion3)
                            print(conclusion4)
                            print("Model 2...")
                            print(B.object + divide + A.object)
                            print(B.object + divide + " "*len(A.object) + divide + C.object)
                        else:
                            """A B, C -B"""
                            print("Model 1...")
                            print(C.__str__() + divide + "-" + B.__str__())
                            print(conclusion7)
                            print(conclusion8)
                            print(conclusion5)
                            print(conclusion6)
                            print("Model 2...")
                            print(B.__str__() + divide + "-" + A.__str__())
                            print(B.object + divide + "-" + A.__str__() + divide + C.__str__())
                            print(conclusion8)
                            conclusions.append(conclusion8)
                else:
                    if model.arg1.all:
                        if not model.denial:
                            """A -B, [C] B"""
                            print(A.object + "-" + divide + " "*len(C.__str__()) + divide + B.object)
                            print(" "*len(A.object) + divide + C.__str__() + divide + B.object)
                            print(conclusion8)
                        else:
                            """A -B, [C] -B"""
                            print(A.object + "-" + divide + " "*len(C.__str__()) + divide + B.object)
                            print(" "*len(A.object) + divide + C.__str__() + divide + "-" + B.__str__())
                    else:
                        if not model.denial:
                            """A -B, C B"""
                            print(A.object + "-" + divide + " "*len(C.__str__()) + divide + B.object)
                            print(" "*len(A.object) + divide + C.object + divide + B.object)
                        else:
                            """A -B, C -B"""
                            print(A.object + "-" + divide + " "*len(C.__str__()) + divide + B.object)
                            print(" "*len(A.object) + divide + C.object + divide + "-" + B.object)
            

        return conclusions

def parse_statements(data):
    statements = data.lower().split("\n")
    if len(statements) > 1:    
        return (MentalModel(statements[0]), MentalModel(statements[1]))
    else:
        print("""The number of statements given was incorrect. See 
                $ python syllogism.py --help
            for correct usage""")
        sys.exit(1)


def main():
    args = parser.parse_args()

    filename = args.file
    f = open(filename)
    print("Inferring from...")
    data = f.read()
    print(data)
    f.close()

    print(separator)
    (mm1, mm2) = parse_statements(data)
    print(mm1)
    print(sub_separator)
    print(mm2)

    print(separator)
    print("The possible inferences are...")
    print(separator)
    conclusions = mm1.join(mm2)
    print(separator)
    print("Conclusions")
    if len(conclusions)==0:
        print("No valid conclusions")
    else:
        for conclusion in conclusions:
            print(conclusion)

if __name__ == '__main__':
    main()
